# Get-UnattendedInstallFile

## SYNOPSIS
Checks several locations for remaining unattended installation files,
which may have deployment credentials.

Author: Will Schroeder (@harmj0y)  
License: BSD 3-Clause  
Required Dependencies: None

## SYNTAX

```
Get-UnattendedInstallFile
```

## DESCRIPTION
{{Fill in the Description}}

## EXAMPLES

### -------------------------- EXAMPLE 1 --------------------------
```
Get-UnattendedInstallFile
```

Finds any remaining unattended installation files.

## PARAMETERS

## INPUTS

## OUTPUTS

### PowerUp.UnattendedInstallFile

Custom PSObject containing results.

## NOTES

## RELATED LINKS

[http://www.fuzzysecurity.com/tutorials/16.html](http://www.fuzzysecurity.com/tutorials/16.html)

